(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define('json2html-lib', ['exports'], factory) :
    (global = global || self, factory(global['json2html-lib'] = {}));
}(this, (function (exports) { 'use strict';

    var Json2html = /** @class */ (function () {
        function Json2html(json, option) {
            if (option === void 0) { option = {}; }
            this.json = json;
            this.options = {
                spaceType: 'space',
                spaceLength: 4,
                spaceBase: 0,
                maxLenght: 0,
                attrPosition: 'alignFirstAttr',
                // type: 'html',
                formatting: 'multiline',
                indent: true,
                noContentTags: [
                    'area',
                    'base',
                    'br',
                    'col',
                    'command',
                    'embed',
                    'hr',
                    'img',
                    'input',
                    'keygen',
                    'link',
                    'meta',
                    'param',
                    'source',
                    'track',
                    'wbr'
                ]
            };
            Object.assign(this.options, option);
        }
        Json2html.prototype.toString = function () {
            return "" + this._getSpacing(0) + this._generate(0, this.json);
        };
        Json2html.prototype._generate = function (lvl, json) {
            var hasContent = !this.options.noContentTags.includes(json.tag.toLowerCase());
            var string = "<" + json.tag + this._generateAttrs(lvl, json) + ">";
            if (hasContent) {
                var tagcontent = this._generateHtml(lvl, json);
                if (tagcontent && this._hasMultiline()) {
                    tagcontent = tagcontent + "\n" + this._getSpacing(lvl);
                }
                string += tagcontent + "</" + json.tag + ">";
            }
            return string;
        };
        Json2html.prototype._generateAttrs = function (lvl, json) {
            var string = '';
            var attrs = json.attrs;
            if (attrs && Object.keys(attrs).length) {
                for (var id in attrs) {
                    if (attrs[id] !== undefined) {
                        var attr = '';
                        switch (this.options.attrPosition) {
                            case 'inline':
                                attr += ' ';
                                break;
                            case 'space':
                                attr += string && this.options.indent && this._hasMultiline()
                                    ? "\n" + this._getSpacing(lvl + 1)
                                    : string += ' ';
                                break;
                            case 'alignTag':
                                attr += string && this.options.indent && this._hasMultiline()
                                    ? "\n" + this._getSpacing(lvl, 1)
                                    : ' ';
                                break;
                            case 'alignFirstAttr':
                                attr += string && this.options.indent && this._hasMultiline()
                                    ? "\n" + this._getSpacing(lvl, json.tag.length + 2)
                                    : ' ';
                                break;
                        }
                        attr += "" + id + (attrs[id] !== null || attrs[id] ? "=\"" + attrs[id] + "\"" : '');
                        string += attr;
                    }
                }
            }
            return string;
        };
        Json2html.prototype._generateHtml = function (lvl, json) {
            var _this = this;
            var string = '';
            if (json.body) {
                if (typeof json.body === 'string') {
                    if (this._hasMultiline()) {
                        string = "\n" + this._getSpacing(lvl + 1);
                    }
                    string += json.body;
                }
                else {
                    json.body.forEach(function (element) {
                        if (_this._hasMultiline()) {
                            string += "\n" + _this._getSpacing(lvl + 1);
                        }
                        string += typeof element === 'string'
                            ? element
                            : _this._generate(lvl + 1, element);
                    });
                }
            }
            return string;
        };
        Json2html.prototype._hasMultiline = function () {
            return this.options.formatting === 'multiline';
        };
        Json2html.prototype._getSpacing = function (lvl, ajout) {
            if (ajout === void 0) { ajout = 0; }
            return this.options.indent
                ? (this.options.spaceType === 'space' ? ' ' : '\t')
                    .repeat((lvl + this.options.spaceBase) * this.options.spaceLength + ajout)
                : '';
        };
        return Json2html;
    }());

    /*
     * Public API Surface of json2html
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.Json2html = Json2html;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=json2html-lib.umd.js.map
