class Json2html {
    constructor(json, option = {}) {
        this.json = json;
        this.options = {
            spaceType: 'space',
            spaceLength: 4,
            spaceBase: 0,
            maxLenght: 0,
            attrPosition: 'alignFirstAttr',
            // type: 'html',
            formatting: 'multiline',
            indent: true,
            noContentTags: [
                'area',
                'base',
                'br',
                'col',
                'command',
                'embed',
                'hr',
                'img',
                'input',
                'keygen',
                'link',
                'meta',
                'param',
                'source',
                'track',
                'wbr'
            ]
        };
        Object.assign(this.options, option);
    }
    toString() {
        return `${this._getSpacing(0)}${this._generate(0, this.json)}`;
    }
    _generate(lvl, json) {
        const hasContent = !this.options.noContentTags.includes(json.tag.toLowerCase());
        let string = `<${json.tag}${this._generateAttrs(lvl, json)}>`;
        if (hasContent) {
            let tagcontent = this._generateHtml(lvl, json);
            if (tagcontent && this._hasMultiline()) {
                tagcontent = `${tagcontent}\n${this._getSpacing(lvl)}`;
            }
            string += `${tagcontent}</${json.tag}>`;
        }
        return string;
    }
    _generateAttrs(lvl, json) {
        let string = '';
        const attrs = json.attrs;
        if (attrs && Object.keys(attrs).length) {
            for (const id in attrs) {
                if (attrs[id] !== undefined) {
                    let attr = '';
                    switch (this.options.attrPosition) {
                        case 'inline':
                            attr += ' ';
                            break;
                        case 'space':
                            attr += string && this.options.indent && this._hasMultiline()
                                ? `\n${this._getSpacing(lvl + 1)}`
                                : string += ' ';
                            break;
                        case 'alignTag':
                            attr += string && this.options.indent && this._hasMultiline()
                                ? `\n${this._getSpacing(lvl, 1)}`
                                : ' ';
                            break;
                        case 'alignFirstAttr':
                            attr += string && this.options.indent && this._hasMultiline()
                                ? `\n${this._getSpacing(lvl, json.tag.length + 2)}`
                                : ' ';
                            break;
                    }
                    attr += `${id}${attrs[id] !== null || attrs[id] ? `="${attrs[id]}"` : ''}`;
                    string += attr;
                }
            }
        }
        return string;
    }
    _generateHtml(lvl, json) {
        let string = '';
        if (json.body) {
            if (typeof json.body === 'string') {
                if (this._hasMultiline()) {
                    string = `\n${this._getSpacing(lvl + 1)}`;
                }
                string += json.body;
            }
            else {
                json.body.forEach((element) => {
                    if (this._hasMultiline()) {
                        string += `\n${this._getSpacing(lvl + 1)}`;
                    }
                    string += typeof element === 'string'
                        ? element
                        : this._generate(lvl + 1, element);
                });
            }
        }
        return string;
    }
    _hasMultiline() {
        return this.options.formatting === 'multiline';
    }
    _getSpacing(lvl, ajout = 0) {
        return this.options.indent
            ? (this.options.spaceType === 'space' ? ' ' : '\t')
                .repeat((lvl + this.options.spaceBase) * this.options.spaceLength + ajout)
            : '';
    }
}

/*
 * Public API Surface of json2html
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Json2html };
//# sourceMappingURL=json2html-lib.js.map
